==> fsx-1.93.0-sources.jar: software/amazon/awscdk/services/fsx/LustreMaintenanceTime.java <==
package software.amazon.awscdk.services.fsx;

/**
 * (experimental) Class for scheduling a weekly manitenance time.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.432Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fsx.$Module.class, fqn = "@aws-cdk/aws-fsx.LustreMaintenanceTime")
public class LustreMaintenanceTime extends software.amazon.jsii.JsiiObject {

    protected LustreMaintenanceTime(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LustreMaintenanceTime(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public LustreMaintenanceTime(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) Converts a day, hour, and minute into a timestamp as used by FSx for Lustre's weeklyMaintenanceStartTime field.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String toTimestamp() {
        return software.amazon.jsii.Kernel.call(this, "toTimestamp", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.fsx.LustreMaintenanceTime}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.fsx.LustreMaintenanceTime> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create() {
            return new Builder();
        }

        private final software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps.Builder props;

        private Builder() {
            this.props = new software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps.Builder();
        }

        /**
         * (experimental) The day of the week for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param day The day of the week for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder day(final software.amazon.awscdk.services.fsx.Weekday day) {
            this.props.day(day);
            return this;
        }

        /**
         * (experimental) The hour of the day (from 0-24) for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param hour The hour of the day (from 0-24) for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder hour(final java.lang.Number hour) {
            this.props.hour(hour);
            return this;
        }

        /**
         * (experimental) The minute of the hour (from 0-59) for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param minute The minute of the hour (from 0-59) for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder minute(final java.lang.Number minute) {
            this.props.minute(minute);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.fsx.LustreMaintenanceTime}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.fsx.LustreMaintenanceTime build() {
            return new software.amazon.awscdk.services.fsx.LustreMaintenanceTime(
                this.props.build()
            );
        }
    }
}

==> fsx-1.182.0-sources.jar: software/amazon/awscdk/services/fsx/LustreMaintenanceTime.java <==
package software.amazon.awscdk.services.fsx;

/**
 * Class for scheduling a weekly manitenance time.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.fsx.*;
 * LustreMaintenanceTime lustreMaintenanceTime = LustreMaintenanceTime.Builder.create()
 *         .day(Weekday.MONDAY)
 *         .hour(123)
 *         .minute(123)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:41.672Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fsx.$Module.class, fqn = "@aws-cdk/aws-fsx.LustreMaintenanceTime")
public class LustreMaintenanceTime extends software.amazon.jsii.JsiiObject {

    protected LustreMaintenanceTime(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LustreMaintenanceTime(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public LustreMaintenanceTime(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Converts a day, hour, and minute into a timestamp as used by FSx for Lustre's weeklyMaintenanceStartTime field.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String toTimestamp() {
        return software.amazon.jsii.Kernel.call(this, "toTimestamp", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.fsx.LustreMaintenanceTime}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.fsx.LustreMaintenanceTime> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private final software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps.Builder props;

        private Builder() {
            this.props = new software.amazon.awscdk.services.fsx.LustreMaintenanceTimeProps.Builder();
        }

        /**
         * The day of the week for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param day The day of the week for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder day(final software.amazon.awscdk.services.fsx.Weekday day) {
            this.props.day(day);
            return this;
        }

        /**
         * The hour of the day (from 0-24) for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param hour The hour of the day (from 0-24) for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hour(final java.lang.Number hour) {
            this.props.hour(hour);
            return this;
        }

        /**
         * The minute of the hour (from 0-59) for maintenance to be performed.
         * <p>
         * @return {@code this}
         * @param minute The minute of the hour (from 0-59) for maintenance to be performed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minute(final java.lang.Number minute) {
            this.props.minute(minute);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.fsx.LustreMaintenanceTime}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.fsx.LustreMaintenanceTime build() {
            return new software.amazon.awscdk.services.fsx.LustreMaintenanceTime(
                this.props.build()
            );
        }
    }
}
